@@ -18,13 +18,14 @@ import dataclasses
 import functools
 import itertools
 import os
-from typing import Any, Callable, Optional, Sequence, Tuple, Union
+from typing import Callable, Optional, Sequence, Tuple, Union
 
 import tensorflow as tf
 import tensorflow_gnn as tfgnn
 from tensorflow_gnn.runner import interfaces
 from tensorflow_gnn.runner.utils import model as model_utils
 from tensorflow_gnn.runner.utils import model_export
+from tensorflow_gnn.runner.utils import parsing as parsing_utils
 
 GraphTensor = tfgnn.GraphTensor
 GraphTensorAndField = Tuple[GraphTensor, tfgnn.Field]
@@ -62,6 +63,7 @@ class _WrappedDatasetProvider(DatasetProvider):
                drop_remainder: bool,
                global_batch_size: int,
                tf_data_service_config: Optional[TFDataServiceConfig] = None):
+    super().__init__()
     self._apply_fn = apply_fn
     self._delegate = delegate
     self._drop_remainder = drop_remainder
@@ -97,7 +99,7 @@ class _WrappedDatasetProvider(DatasetProvider):
 
 def _make_parsing_model(gtspec: GraphTensorSpec) -> tf.keras.Model:
   """Builds a `tf.keras.Model` that parses GraphTensors."""
-  examples = tf.keras.layers.Input(
+  examples = tf.keras.Input(
       shape=(),
       dtype=tf.string,
       name="examples")  # Name seen in SignatureDef.
@@ -125,7 +127,7 @@ def _make_preprocessing_model(
     outputs are (`GraphTensor`, `tfgnn.Field`, `tfgnn.Field`) as model
     input, label and mask (respectively).
   """
-  gt = tf.keras.layers.Input(type_spec=gtspec)
+  gt = tf.keras.Input(type_spec=gtspec)
   x = gt.merge_batch_to_components()
 
   if size_constraints is not None:
@@ -139,7 +141,7 @@ def _make_preprocessing_model(
   for fn in itertools.chain(preprocessors, (task_preprocessor,)):
     output = fn(x)
 
-    if isinstance(output, collections.Sequence):
+    if isinstance(output, collections.abc.Sequence):
       x, *ys = output
       if len(ys) == 1:
         yy = ys[0]
@@ -171,33 +173,6 @@ _map_over_dataset = functools.partial(
     num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
 
-def _maybe_parse(gtspec: GraphTensorSpec) -> Callable[[Any], GraphTensor]:
-  """Returns a callable to parse (or assert the spec of) dataset elements."""
-  parse_example = tfgnn.keras.layers.ParseExample(gtspec)
-  # Relax the spec for potential comparisons.
-  relaxed = gtspec.relax(num_components=True, num_nodes=True, num_edges=True)
-  def fn(element):
-    # Use `getattr` to account for types without a `dtype` (e.g. `GraphTensor`).
-    if getattr(element, "dtype", None) == tf.string:
-      gt = parse_example(element)
-    elif not tfgnn.is_graph_tensor(element):
-      raise ValueError(f"Expected `GraphTensor` (got {element})")
-    else:
-      # Access protected member `_unbatch` to avoid any potential
-      # `merge_batch_to_components` work.
-      actual = element.spec._unbatch().relax(  # pylint: disable=protected-access
-          num_components=True,
-          num_nodes=True,
-          num_edges=True)
-      if actual != relaxed:
-        raise ValueError(
-            f"Expected a `GraphTensor` of spec {relaxed} (got {actual})")
-      else:
-        gt = element
-    return gt
-  return fn
-
-
 def _per_replica_batch_size(global_batch_size: int, num_replicas: int) -> int:
   if global_batch_size % num_replicas != 0:
     raise ValueError(f"The `global_batch_size` {global_batch_size} is not "
@@ -235,8 +210,11 @@ def run(*,
     optimizer_fn: Returns a `tf.keras.optimizers.Optimizer` for use in training.
     trainer: A `Trainer.`
     task: A `Task.`
-    gtspec: A `GraphTensorSpec` for parsing the GraphTensors in the
-      `train` and `valid` datasets.
+    gtspec: A `GraphTensorSpec` matching the elements of `train` and `valid`
+      datasets. If `train` or `valid` contain `tf.string` elements, this
+      `GraphTensorSpec` is used for parsing; otherwise, `train` or `valid` are
+      expected to contain `GraphTensor` elements whose relaxed spec matches
+      `gtspec.`
     global_batch_size: The `tf.data.Dataset` global batch size for both training
       and validation.
     epochs: The epochs to train.
@@ -283,7 +261,7 @@ def run(*,
                *,
                filter_fn: Optional[Callable[..., bool]] = None,
                size_constraints: Optional[SizeConstraints] = None):
-    ds = _map_over_dataset(ds, parsing_model)
+    ds = parsing_utils.maybe_parse_graph_tensor_dataset(ds, gtspec)
     if filter_fn is not None:
       ds = ds.filter(filter_fn)
     if size_constraints is not None:
@@ -338,7 +316,7 @@ def run(*,
         global_batch_size)
 
   def adapted_model_fn():
-    if isinstance(preprocess_model.output, collections.Sequence):
+    if isinstance(preprocess_model.output, collections.abc.Sequence):
       x, *_ = preprocess_model.output
     else:
       x = preprocess_model.output
