@@ -53,7 +53,7 @@ class _Regression(interfaces.Task):
     logits = tf.keras.layers.Dense(
         self._units,
         name="logits")(activations)  # Name seen in SignatureDef.
-    return tf.keras.Model(model.inputs, logits)
+    return tf.keras.Model(model.input, logits)
 
   def preprocess(self, gt: tfgnn.GraphTensor) -> tfgnn.GraphTensor:
     return gt
@@ -84,12 +84,12 @@ class _GraphRegression(_Regression):
     self._state_name = state_name
     self._reduce_type = reduce_type
 
-  def gather_activations(self, gt: tfgnn.GraphTensor) -> tfgnn.Field:
-    return tfgnn.pool_nodes_to_context(
-        gt,
-        self._node_set_name,
+  def gather_activations(self, gt: tfgnn.GraphTensor) -> tf.Tensor:
+    return tfgnn.keras.layers.Pool(
+        tfgnn.CONTEXT,
         self._reduce_type,
-        feature_name=self._state_name)
+        node_set_name=self._node_set_name,
+        feature_name=self._state_name)(gt)
 
 
 class _RootNodeRegression(_Regression):
